ocsd_generic_trace_elem

Type Alias ocsd_generic_trace_elem 

pub type ocsd_generic_trace_elem = _ocsd_generic_trace_elem;

Aliased Type

#[repr(C)]
pub struct ocsd_generic_trace_elem { pub elem_type: u32, pub isa: u32, pub st_addr: u64, pub en_addr: u64, pub context: _ocsd_pe_context, pub timestamp: u64, pub cycle_count: u32, pub last_i_type: u32, pub last_i_subtype: u32, pub __bindgen_anon_1: _ocsd_generic_trace_elem__bindgen_ty_1, pub __bindgen_anon_2: _ocsd_generic_trace_elem__bindgen_ty_2, pub ptr_extended_data: *const c_void, }

Fields

elem_type: u32

< Element type - remaining data interpreted according to this value

isa: u32

< instruction set for executed instructions

st_addr: u64

< start address for instruction execution range / inaccessible code address / data address

en_addr: u64

< end address (exclusive) for instruction execution range.

context: _ocsd_pe_context

< PE Context

timestamp: u64

< timestamp value for TS element type, or timestamp for types with associated TS

cycle_count: u32

< cycle count for explicit cycle count element, or count for element with associated cycle count

last_i_type: u32

< Last instruction type if instruction execution range

last_i_subtype: u32

< sub type for last instruction in range

__bindgen_anon_1: _ocsd_generic_trace_elem__bindgen_ty_1__bindgen_anon_2: _ocsd_generic_trace_elem__bindgen_ty_2ptr_extended_data: *const c_void

< pointer to extended data buffer (data trace, sw trace payload) / custom structure